@@ -1,15 +1,12 @@
-#' A class that defines a collection of Excel styles as used by the openxlsx
+#' R6 class that defines a collection of Excel styles as used by the `openxlsx`
 #' package.
 #'
-#' The TableOpenXlsxStyles class stores a collection of TableTableOpenXlsx style
-#' objects.
+#' @description
+#' The `TableOpenXlsxStyles` class stores a collection of `TableTableOpenXlsx`
+#' style objects.
 #'
 #' @docType class
 #' @importFrom R6 R6Class
-#' @import jsonlite
-#' @export
-#' @return Object of \code{\link{R6Class}} with properties and methods that
-#'   define styles/a theme for a table.
 #' @format \code{\link{R6Class}} object.
 #' @examples
 #' # This class should not be used by end users.  It is an internal class
@@ -23,30 +20,14 @@
 #'                          topRowNumber=1, leftMostColumnNumber=1,
 #'                          applyStyles=TRUE, mapStylesFromCSS=TRUE)
 #' # Use saveWorkbook() to save the Excel file.
-#' @field parentTable Owning table.
-
-#' @section Methods:
-#' \describe{
-#'   \item{Documentation}{For more complete explanations and examples please see
-#'   the extensive vignettes supplied with this package.}
-#'   \item{\code{new(...)}}{Create a new set of styles, specifying the field
-#'   values documented above.}
-#'
-#'   \item{\code{findNamedStyle(baseStyleName)}}{Find an existing openxlsx style
-#'   matching the name of a base style.}
-#'   \item{\code{findOrAddStyle(action="findOrAdd", baseStyleName=NULL,
-#'   isBaseStyle=NULL, style=NULL, mapFromCss=TRUE)}}{Find an existing openxlsx
-#'   style and/or add a new openxlsx style matching a base style and/or
-#'   TableStyle object.}
-#'   \item{\code{addNamedStyles(mapFromCss=TRUE)}}{Populate the OpenXlsx styles
-#'   based on the styles defined in the table.}
-#'   \item{\code{asList()}}{Get a list representation of the styles.}
-#'   \item{\code{asJSON()}}{Get a JSON representation of the styles.}
-#'   \item{\code{asString()}}{Get a text representation of the styles.}
-#' }
 
 TableOpenXlsxStyles <- R6::R6Class("TableOpenXlsxStyles",
   public = list(
+
+    #' @description
+    #' Create a new `TableOpenXlsxStyles` object.
+    #' @param parentTable Owning table.
+    #' @return No return value.
     initialize = function(parentTable) {
       if(parentTable$argumentCheckMode > 0) {
         checkArgument(parentTable$argumentCheckMode, FALSE, "TableOpenXlsxStyles", "initialize", parentTable, missing(parentTable), allowMissing=FALSE, allowNull=FALSE, allowedClasses="BasicTable")
@@ -56,12 +37,22 @@ TableOpenXlsxStyles <- R6::R6Class("TableOpenXlsxStyles",
       private$p_styles <- list()
       if(private$p_parentTable$traceEnabled==TRUE) private$p_parentTable$trace("TableOpenXlsxStyles$new", "Created new Table OpenXlsx Styles.")
     },
+
+    #' @description
+    #' Clear the collection removing all styles.
+    #' @return No return value.
     clearStyles = function() {
       if(private$p_parentTable$traceEnabled==TRUE) p
       private$p_parentTable$trace("TableOpenXlsxStyles$clearStyles", "Clearin styles...")
       private$p_styles <- list()
       if(private$p_parentTable$traceEnabled==TRUE) private$p_parentTable$trace("TableOpenXlsxStyles$clearStyles", "Cleared styles.")
     },
+
+    #' @description
+    #' Find a style in the collection matching the specified base style name.
+    #' @param baseStyleName The style name to find.
+    #' @return A `TableTableOpenXlsx` object that is the style matching the
+    #'   specified base style name or `NULL` otherwise.
     findNamedStyle = function(baseStyleName) {
       if(private$p_parentTable$argumentCheckMode > 0) {
         checkArgument(private$p_parentTable$argumentCheckMode, FALSE, "TableOpenXlsxStyles", "initialize", baseStyleName, missing(baseStyleName), allowMissing=TRUE, allowNull=TRUE, allowedClasses="character")
@@ -81,6 +72,21 @@ TableOpenXlsxStyles <- R6::R6Class("TableOpenXlsxStyles",
       if(private$p_parentTable$traceEnabled==TRUE) private$p_parentTable$trace("TableOpenXlsxStyles$findNamedStyle", "Found named style.")
       return(invisible(matchedStyle))
     },
+
+    #' @description
+    #' Find a style in the collection matching the specified base style name and
+    #' style properties.  If there is no matching style, then optionally add a
+    #' new style.
+    #' @param action The action to carry out.  Must be one of "find", "add" or
+    #'   "findOrAdd" (default).
+    #' @param baseStyleName The style name to find/add.
+    #' @param isBaseStyle Is the style to be found/added a base style?
+    #' @param style A `TableStyle` object specifying style properties to be found/added.
+    #' @param mapFromCss `TRUE` (default) to map the basictabler CSS styles to
+    #'   corresponding Excel styles, `FALSE` to apply only the specified xl
+    #'   styles.
+    #' @return A `TableTableOpenXlsx` object that is the style matching the
+    #'   specified base style name or `NULL` otherwise.
     findOrAddStyle = function(action="findOrAdd", baseStyleName=NULL, isBaseStyle=NULL, style=NULL, mapFromCss=TRUE) {
       if(private$p_parentTable$argumentCheckMode > 0) {
         checkArgument(private$p_parentTable$argumentCheckMode, FALSE, "TableOpenXlsxStyles", "findOrAddStyle", action, missing(action), allowMissing=TRUE, allowNull=FALSE, allowedClasses="character", allowedValues=c("find", "add", "findOrAdd"))
@@ -379,6 +385,14 @@ TableOpenXlsxStyles <- R6::R6Class("TableOpenXlsxStyles",
       if(private$p_parentTable$traceEnabled==TRUE) private$p_parentTable$trace("TableOpenXlsxStyles$findOrAddStyle", "Found and/or added style.")
       return(matchedStyle)
     },
+
+    #' @description
+    #' Populate the OpenXlsx styles
+    #'   based on the styles defined in the table.
+    #' @param mapFromCss `TRUE` (default) to map the basictabler CSS styles to
+    #'   corresponding Excel styles, `FALSE` to apply only the specified xl
+    #'   styles.
+    #' @return No return value.
     addNamedStyles = function(mapFromCss=TRUE) {
       if(private$p_parentTable$argumentCheckMode > 0) {
         checkArgument(private$p_parentTable$argumentCheckMode, FALSE, "TableOpenXlsxStyles", "addNamedStyles", mapFromCss, missing(mapFromCss), allowMissing=TRUE, allowNull=FALSE, allowedClasses="logical")
@@ -392,6 +406,10 @@ TableOpenXlsxStyles <- R6::R6Class("TableOpenXlsxStyles",
       }
       if(private$p_parentTable$traceEnabled==TRUE) private$p_parentTable$trace("TableOpenXlsxStyles$addNamedStyles", "Added named styles.")
     },
+
+    #' @description
+    #' Return the contents of this object as a list for debugging.
+    #' @return A list of various object properties.
     asList = function() {
       lst <- list()
       if(length(private$p_styles) > 0) {
@@ -401,7 +419,25 @@ TableOpenXlsxStyles <- R6::R6Class("TableOpenXlsxStyles",
       }
       return(invisible(lst))
     },
-    asJSON = function() { return(jsonlite::toJSON(self$asList())) },
+
+    #' @description
+    #' Return the contents of this object as JSON for debugging.
+    #' @return A JSON representation of various object properties.
+    asJSON = function() {
+      if (!requireNamespace("jsonlite", quietly = TRUE)) {
+        stop("The jsonlite package is needed to convert to JSON.  Please install the jsonlite package.", call. = FALSE)
+      }
+      jsonliteversion <- utils::packageDescription("jsonlite")$Version
+      if(numeric_version(jsonliteversion) < numeric_version("1.1")) {
+        stop("Version 1.1 or above of the jsonlite package is needed to convert to JSON.  Please install an updated version of the jsonlite package.", call. = FALSE)
+      }
+      return(jsonlite::toJSON(self$asList()))
+    },
+
+    #' @description
+    #' Return the contents of this object as a string for debugging.
+    #' @param seperator Delimiter used to combine multiple values into a string.
+    #' @return A character representation of various object properties.
     asString = function(seperator=", ") {
       if(private$p_parentTable$argumentCheckMode > 0) {
         checkArgument(private$p_parentTable$argumentCheckMode, FALSE, "TableOpenXlsxStyles", "asString", seperator, missing(seperator), allowMissing=TRUE, allowNull=FALSE, allowedClasses="character")
@@ -419,7 +455,11 @@ TableOpenXlsxStyles <- R6::R6Class("TableOpenXlsxStyles",
     }
   ),
   active = list(
+
+    #' @field count The number of styles in the collection.
     count = function(value) { return(invisible(length(private$p_styles))) },
+
+    #' @field styles A list of `TableOpenXlsxStyle` objects that comprise the collection.
     styles = function(value) { return(invisible(private$p_styles)) }
   ),
   private = list(
